"""
Этот модуль содержит команды для управления спрайтами.
Спрайт - это какой-то элемент игры, который перемещается по экрану и взаимодействует с другими персонажами.

Например, в игре "футбол", каждый игрок, судья и даже мяч являются спрайтами.

Методы add, remove, add_text - создание и удаление спрайтов.

Методы show, hide, is_visible - показ и скрытие спрайтов с экрана и узнавание его видимости.

Методы set... - меняют настройки спрайта. Костюм, угол поворота, отражение слева на право и т.п.

Методы get... - получение положения спрайта или его настроек.

Методы move...- перемещение спрайта.

Методы is... - проверка, что спрайт подходит под какие-то условия. Например, что спрайт пересекается с другим спрайтом.
"""
# from wrap_py import sprite


def add(sprite_type: str, x: int, y: int, visible: bool = True, costume=None):
    """
    Добавляет на экран спрайт указанного типа.

    :param sprite_type: Строка с названием. Должна совпадать с названием папки в каталоге спрайтов.
    :param x: координата x, по которой появится спрайт
    :param y: координата y, по которой появится спрайт
    :param visible: Видимость. Если True - спрайт будет создан видимым. False - невидимым.
    :param costume: Строка с названием костюма спрайта. Должна совпадать с названием костюма спрайта. Расширение (например .png) указывать не нужно.
    :return: Возвращает число - уникальный номер созданного спрайта.
    """
    return sprite.add_sprite(sprite_type, x, y, visible, costume)


def move_to_pos(id: int, x: int, y: int):
    """
    Перемещает спрайт на новое место на экране.

    :param id: Уникальный номер спрайта, который нужно переместить.
    :return: None
    """
    return sprite.move_sprite_to(id, x, y)


def w1():
    global sprite
    from wrap_py import sprite


w1()
